
# This file was generated by 'versioneer.py' (0.17) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2017-11-30T14:00:59-0600",
 "dirty": false,
 "error": null,
 "full-revisionid": "bb2b80f1856dad0bedd6d6336cf0590761de94d1",
 "version": "3.0.31"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
